emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master dd35925: Declare unused vhdl code in align.el obsol


From: Stefan Kangas
Subject: [Emacs-diffs] master dd35925: Declare unused vhdl code in align.el obsolete
Date: Fri, 4 Oct 2019 11:13:13 -0400 (EDT)

branch: master
commit dd3592564aaaee15077800a093c9e04f5da898dc
Author: Stefan Kangas <address@hidden>
Commit: Stefan Kangas <address@hidden>

    Declare unused vhdl code in align.el obsolete
    
    * lisp/align.el (align-vhdl-rules-list, align-set-vhdl-rules): Declare
    obsolete.  (Bug#6207)
    (align-dq-string-modes, align-open-comment-modes): Move vhdl-mode to
    definition instead of adding it later.
---
 lisp/align.el | 16 +++++-----------
 1 file changed, 5 insertions(+), 11 deletions(-)

diff --git a/lisp/align.el b/lisp/align.el
index cd72d52..d83f834 100644
--- a/lisp/align.el
+++ b/lisp/align.el
@@ -206,7 +206,7 @@ If nil, then no messages will ever be printed to the 
minibuffer."
 
 (defcustom align-dq-string-modes
   (append align-lisp-modes align-c++-modes align-perl-modes
-         '(python-mode))
+          '(python-mode vhdl-mode))
   "A list of modes where double quoted strings should be excluded."
   :type '(repeat symbol)
   :group 'align)
@@ -219,7 +219,7 @@ If nil, then no messages will ever be printed to the 
minibuffer."
 
 (defcustom align-open-comment-modes
   (append align-lisp-modes align-c++-modes align-perl-modes
-         '(python-mode makefile-mode))
+          '(python-mode makefile-mode vhdl-mode))
   "A list of modes with a single-line comment syntax.
 These are comments as in Lisp, which have a beginning, but end with
 the line (i.e., `comment-end' is an empty string)."
@@ -805,9 +805,7 @@ See the variable `align-exclude-rules-list' for more 
details.")
 (defvar align-regexp-history nil
   "Input history for the full user-entered regex in `align-regexp'")
 
-;; Sample extension rule set, for vhdl-mode.  This should properly be
-;; in vhdl-mode.el itself.
-
+;; Sample extension rule set for vhdl-mode.  This is now obsolete.
 (defcustom align-vhdl-rules-list
   `((vhdl-declaration
      (regexp   . "\\(signal\\|variable\\|constant\\)\\(\\s-+\\)\\S-")
@@ -842,18 +840,14 @@ See the variable `align-exclude-rules-list' for more 
details.")
   "Alignment rules for `vhdl-mode'.  See `align-rules-list' for more info."
   :type align-rules-list-type
   :group 'align)
-
 (put 'align-vhdl-rules-list 'risky-local-variable t)
+(make-obsolete-variable 'align-vhdl-rules-list "no longer used." "27.1")
 
 (defun align-set-vhdl-rules ()
   "Setup the `align-mode-rules-list' variable for `vhdl-mode'."
+  (declare (obsolete nil "27.1"))
   (setq align-mode-rules-list align-vhdl-rules-list))
 
-(add-hook 'vhdl-mode-hook 'align-set-vhdl-rules)
-
-(add-to-list 'align-dq-string-modes 'vhdl-mode)
-(add-to-list 'align-open-comment-modes 'vhdl-mode)
-
 ;;; User Functions:
 
 ;;;###autoload



reply via email to

[Prev in Thread] Current Thread [Next in Thread]